@@ -41,9 +41,9 @@ import java.io.IOException;
 import java.io.Reader;
 import java.util.LinkedList;
 import net.sourceforge.guacamole.GuacamoleException;
+import net.sourceforge.guacamole.GuacamoleServerException;
 import net.sourceforge.guacamole.protocol.GuacamoleInstruction;
 import net.sourceforge.guacamole.protocol.GuacamoleInstruction.Operation;
-import org.apache.commons.lang3.ArrayUtils;
 
 /**
  * A GuacamoleReader which wraps a standard Java Reader, using that Reader as
@@ -79,7 +79,7 @@ public class ReaderGuacamoleReader implements GuacamoleReader {
             return input.ready() || usedLength != 0;
         }
         catch (IOException e) {
-            throw new GuacamoleException(e);
+            throw new GuacamoleServerException(e);
         }
     }
 
@@ -144,7 +144,7 @@ public class ReaderGuacamoleReader implements GuacamoleReader {
 
                             // Handle invalid terminator characters
                             else if (terminator != ',')
-                                throw new GuacamoleException("Element terminator of instruction was not ';' nor ','");
+                                throw new GuacamoleServerException("Element terminator of instruction was not ';' nor ','");
                             
                         }
 
@@ -156,7 +156,7 @@ public class ReaderGuacamoleReader implements GuacamoleReader {
 
                     // Otherwise, parse error
                     else
-                        throw new GuacamoleException("Non-numeric character in element length.");
+                        throw new GuacamoleServerException("Non-numeric character in element length.");
 
                 }
 
@@ -179,7 +179,7 @@ public class ReaderGuacamoleReader implements GuacamoleReader {
 
         }
         catch (IOException e) {
-            throw new GuacamoleException(e);
+            throw new GuacamoleServerException(e);
         }
 
     }
@@ -201,8 +201,19 @@ public class ReaderGuacamoleReader implements GuacamoleReader {
         LinkedList<String> elements = new LinkedList<String>();
         while (elementStart < instructionBuffer.length) {
 
-            // Find end of length 
-            int lengthEnd = ArrayUtils.indexOf(instructionBuffer, '.', elementStart);
+            // Find end of length
+            int lengthEnd = -1;
+            for (int i=elementStart; i<instructionBuffer.length; i++) {
+                if (instructionBuffer[i] == '.') {
+                    lengthEnd = i;
+                    break;
+                }
+            }
+
+            // read() is required to return a complete instruction. If it does
+            // not, this is a severe internal error.
+            if (lengthEnd == -1)
+                throw new GuacamoleServerException("Read returned incomplete instruction.");
 
             // Parse length
             int length = Integer.parseInt(new String(
