@@ -146,6 +146,16 @@ public class GuacamoleTunnel {
         return uuid;
     }
 
+    /**
+     * Returns the GuacamoleSocket used by this GuacamoleTunnel for reading
+     * and writing.
+     * 
+     * @return The GuacamoleSocket used by this GuacamoleTunnel.
+     */
+    public GuacamoleSocket getSocket() {
+        return socket;
+    }
+
     /**
      * Release all resources allocated to this GuacamoleTunnel.
      * 
@@ -156,4 +166,13 @@ public class GuacamoleTunnel {
         socket.close();
     }
 
+    /**
+     * Returns whether this GuacamoleTunnel is open, or has been closed.
+     * 
+     * @return true if this GuacamoleTunnel is open, false if it is closed.
+     */
+    public boolean isOpen() {
+        return socket.isOpen();
+    }
+    
 }
