@@ -41,6 +41,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.Properties;
 import net.sourceforge.guacamole.GuacamoleException;
+import net.sourceforge.guacamole.GuacamoleServerException;
 
 /**
  * Simple utility class for reading properties from the guacamole.properties
@@ -86,11 +87,13 @@ public class GuacamoleProperties {
             if (stream == null)
                 throw new IOException("Resource /guacamole.properties not found.");
 
-            properties.load(stream);
+            // Load properties, always close stream
+            try { properties.load(stream); }
+            finally { stream.close(); }
 
         }
         catch (IOException e) {
-            exception = new GuacamoleException("Error reading guacamole.properties", e);
+            exception = new GuacamoleServerException("Error reading guacamole.properties", e);
         }
 
     }
@@ -135,7 +138,7 @@ public class GuacamoleProperties {
 
         Type value = getProperty(property);
         if (value == null)
-            throw new GuacamoleException("Property " + property.getName() + " is required.");
+            throw new GuacamoleServerException("Property " + property.getName() + " is required.");
 
         return value;
         
