@@ -58,6 +58,7 @@ import net.sourceforge.guacamole.protocol.GuacamoleInstruction.Operation;
 public class ConfiguredGuacamoleSocket implements GuacamoleSocket {
 
     private GuacamoleSocket socket;
+    private GuacamoleConfiguration config;
 
     /**
      * Creates a new ConfiguredGuacamoleSocket which uses the given
@@ -70,7 +71,8 @@ public class ConfiguredGuacamoleSocket implements GuacamoleSocket {
      * @throws GuacamoleException If an error occurs while completing the
      *                            initial protocol handshake.
      */
-    public ConfiguredGuacamoleSocket(GuacamoleSocket socket, GuacamoleConfiguration config) throws GuacamoleException {
+    public ConfiguredGuacamoleSocket(GuacamoleSocket socket,
+            GuacamoleConfiguration config) throws GuacamoleException {
 
         this.socket = socket;
 
@@ -106,6 +108,17 @@ public class ConfiguredGuacamoleSocket implements GuacamoleSocket {
 
     }
 
+    /**
+     * Returns the GuacamoleConfiguration used to configure this
+     * ConfiguredGuacamoleSocket.
+     * 
+     * @return The GuacamoleConfiguration used to configure this
+     *         ConfiguredGuacamoleSocket.
+     */
+    public GuacamoleConfiguration getConfiguration() {
+        return config;
+    }
+
     @Override
     public GuacamoleWriter getWriter() {
         return socket.getWriter();
@@ -121,4 +134,9 @@ public class ConfiguredGuacamoleSocket implements GuacamoleSocket {
         socket.close();
     }
 
+    @Override
+    public boolean isOpen() {
+        return socket.isOpen();
+    }
+
 }
